Module path_iterator

Module path_iterator 

Available on crate feature api-23 only.

Structs

OH_Drawing_PathIteratorVerb
Enumerates the path operation types contained in an iterator. It is used to read path operation instructions.

Functions

OH_Drawing_PathIteratorCreate
Creates an OH_Drawing_PathIterator object from a path.
OH_Drawing_PathIteratorDestroy
Destroys an OH_Drawing_PathIterator object and reclaims the memory occupied by the object.
OH_Drawing_PathIteratorHasNext
Checks if there is a next operation in the path operation iterator.
OH_Drawing_PathIteratorNext
Retrieves the next operation in the path and moves the iterator to that operation.
OH_Drawing_PathIteratorPeek
Retrieves the next operation in this path, without moving the iterator.