#[repr(transparent)]pub struct DrawingErrorCode(pub NonZero<c_uint>);api-12 only.Expand description
Enumerates error codes of drawing.
Available since API-level: 12
Tuple Fields
0: NonZero<c_uint>Implementations
Sourceimpl DrawingErrorCode
impl DrawingErrorCode
Sourcepub const NO_PERMISSION: DrawingErrorCode
pub const NO_PERMISSION: DrawingErrorCode
Permission verification failed.
Sourcepub const INVALID_PARAMETER: DrawingErrorCode
pub const INVALID_PARAMETER: DrawingErrorCode
Invalid input parameter. For example, the pointer in the parameter is a nullptr.
Sourcepub const PARAMETER_OUT_OF_RANGE: DrawingErrorCode
pub const PARAMETER_OUT_OF_RANGE: DrawingErrorCode
The parameter is not in the valid range.
Sourcepub const ALLOCATION_FAILED: DrawingErrorCode
Available on crate feature api-13 only.
pub const ALLOCATION_FAILED: DrawingErrorCode
api-13 only.mem allocate failed.
Available since API-level: 13
Sourcepub const ATTRIBUTE_ID_MISMATCH: DrawingErrorCode
Available on crate feature api-21 only.
pub const ATTRIBUTE_ID_MISMATCH: DrawingErrorCode
api-21 only.The attribute id is not recognized or supported.
Available since API-level: 21
Sourcepub const INCORRECT_PARAMETER: DrawingErrorCode
Available on crate feature api-22 only.
pub const INCORRECT_PARAMETER: DrawingErrorCode
api-22 only.incorrect input parameter. The possible cause is that the provided pointer is null.
Available since API-level: 22
Sourcepub const FILE_NOT_FOUND: DrawingErrorCode
Available on crate feature api-23 only.
pub const FILE_NOT_FOUND: DrawingErrorCode
api-23 only.File not found. The specified file does not exist or the path is incorrect..
Available since API-level: 23
Sourcepub const OPEN_FILE_FAILED: DrawingErrorCode
Available on crate feature api-23 only.
pub const OPEN_FILE_FAILED: DrawingErrorCode
api-23 only.Failed to open the file. The file cannot be opened due to permission or I/O issues.
Available since API-level: 23
Sourcepub const FILE_SEEK_FAILED: DrawingErrorCode
Available on crate feature api-23 only.
pub const FILE_SEEK_FAILED: DrawingErrorCode
api-23 only.File seek failed. The system failed to reposition the file read pointer..
Available since API-level: 23
Sourcepub const GET_FILE_SIZE_FAILED: DrawingErrorCode
Available on crate feature api-23 only.
pub const GET_FILE_SIZE_FAILED: DrawingErrorCode
api-23 only.Failed to get the file size. The system was unable to obtain the file size information.
Available since API-level: 23
Sourcepub const READ_FILE_FAILED: DrawingErrorCode
Available on crate feature api-23 only.
pub const READ_FILE_FAILED: DrawingErrorCode
api-23 only.Failed to read the file. The file could not be read completely or contains unreadable data.
Available since API-level: 23
Sourcepub const EMPTY_FILE: DrawingErrorCode
Available on crate feature api-23 only.
pub const EMPTY_FILE: DrawingErrorCode
api-23 only.Empty file. The specified file is empty and contains no valid data.
Available since API-level: 23
Sourcepub const FILE_CORRUPTED: DrawingErrorCode
Available on crate feature api-23 only.
pub const FILE_CORRUPTED: DrawingErrorCode
api-23 only.Corrupted file. The file content is invalid or damaged and cannot be parsed.
Available since API-level: 23