pub unsafe extern "C" fn OH_Drawing_CreateComposePathEffect(
outer: *mut OH_Drawing_PathEffect,
inner: *mut OH_Drawing_PathEffect,
) -> *mut OH_Drawing_PathEffectAvailable on crate features
api-12 and api-18 only.Expand description
Creates an OH_Drawing_PathEffect object that is a combination of paths, applying the inner path effect first and then the outer path effect.
Required System Capabilities: SystemCapability.Graphic.Graphic2D.NativeDrawing
Arguments
-
outer- Indicates an OH_Drawing_PathEffect object -
inner- Indicates an OH_Drawing_PathEffect object
Returns
- Returns the pointer to the OH_Drawing_PathEffect object created.
Available since API-level: 18
Version: 1.0