Available on crate feature
api-23 only.Structs
- OH_
Drawing_ Path Iterator Verb - Enumerates the path operation types contained in an iterator. It is used to read path operation instructions.
Functions
- OH_
Drawing_ ⚠Path Iterator Create - Creates an OH_Drawing_PathIterator object from a path.
- OH_
Drawing_ ⚠Path Iterator Destroy - Destroys an OH_Drawing_PathIterator object and reclaims the memory occupied by the object.
- OH_
Drawing_ ⚠Path Iterator HasNext - Checks if there is a next operation in the path operation iterator.
- OH_
Drawing_ ⚠Path Iterator Next - Retrieves the next operation in the path and moves the iterator to that operation.
- OH_
Drawing_ ⚠Path Iterator Peek - Retrieves the next operation in this path, without moving the iterator.