pub unsafe extern "C" fn OH_Drawing_RectCreateArray(
size: usize,
) -> *mut OH_Drawing_ArrayAvailable on crate features
api-11 and api-18 only.Expand description
Creates an OH_Drawing_Array object, which is used to store multiple OH_Drawing_Rect object.
Required System Capabilities: SystemCapability.Graphic.Graphic2D.NativeDrawing
Arguments
size- Indicates the size of the array object.
Returns
- Returns the pointer to the OH_Drawing_Array object created. If nullptr is returned, the creation fails. The possible cause of the failure is that the available memory is empty, or size is invalid.
Available since API-level: 18
Version: 1.0